@@ -6,8 +6,8 @@ use Moo;
 use File::DataClass::Types qw( ArrayRef Bool HashRef Result Undef );
 
 has 'found'  => is => 'ro', isa => Bool,     default => 0;
-has 'labels' => is => 'ro', isa => HashRef,  default => sub { return {} };
-has 'list'   => is => 'ro', isa => ArrayRef, default => sub { return [] };
+has 'labels' => is => 'ro', isa => HashRef,  builder => sub { {} };
+has 'list'   => is => 'ro', isa => ArrayRef, builder => sub { [] };
 has 'result' => is => 'ro', isa => Result | Undef;
 
 1;
@@ -87,7 +87,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2014 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
